import { GC_MODES } from 'pixijs/constants';
import type { ExtensionMetadata } from 'pixijs/extensions';
import type { Renderer } from '../Renderer';
import type { RenderTexture } from '../renderTexture/RenderTexture';
import type { ISystem } from '../system/ISystem';
import type { Texture } from './Texture';
export interface IUnloadableTexture {
    _texture: Texture | RenderTexture;
    children: IUnloadableTexture[];
}
/**
 * System plugin to the renderer to manage texture garbage collection on the GPU,
 * ensuring that it does not get clogged up with textures that are no longer being used.
 * @memberof PIXI
 */
export declare class TextureGCSystem implements ISystem {
    /**
     * Default Garbage Collection mode.
     * @static
     * @type {PIXI.GC_MODES}
     * @default PIXI.GC_MODES.AUTO
     */
    static defaultMode: GC_MODES;
    /**
     * Default Garbage Collection max idle.
     * @static
     * @default 3600
     */
    static defaultMaxIdle: number;
    /**
     * Default Garbage Collection maximum check count.
     * @static
     * @default 600
     */
    static defaultCheckCountMax: number;
    /** @ignore */
    static extension: ExtensionMetadata;
    /**
     * Count
     * @readonly
     */
    count: number;
    /**
     * Check count
     * @readonly
     */
    checkCount: number;
    /**
     * Maximum idle time, in seconds
     * @see PIXI.TextureGCSystem.defaultMaxIdle
     */
    maxIdle: number;
    /**
     * Maximum number of item to check
     * @see PIXI.TextureGCSystem.defaultCheckCountMax
     */
    checkCountMax: number;
    /**
     * Current garbage collection mode
     * @see PIXI.TextureGCSystem.defaultMode
     */
    mode: GC_MODES;
    private renderer;
    /** @param renderer - The renderer this System works for. */
    constructor(renderer: Renderer);
    /**
     * Checks to see when the last time a texture was used
     * if the texture has not been used for a specified amount of time it will be removed from the GPU
     */
    protected postrender(): void;
    /**
     * Checks to see when the last time a texture was used
     * if the texture has not been used for a specified amount of time it will be removed from the GPU
     */
    run(): void;
    /**
     * Removes all the textures within the specified displayObject and its children from the GPU
     * @param {PIXI.DisplayObject} displayObject - the displayObject to remove the textures from.
     */
    unload(displayObject: IUnloadableTexture): void;
    destroy(): void;
}
